summaryrefslogtreecommitdiffstats
path: root/lib/kofficecore/KoDocument.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2011-12-19 11:38:41 -0600
commitf0de9e167e289ab7dc33e57f077c1f04ec7c68c8 (patch)
tree1fc538e179833e62caec21956bfe47a252be5a72 /lib/kofficecore/KoDocument.h
parent11191ef0b9908604d1d7aaca382b011ef22c454c (diff)
downloadkoffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.tar.gz
koffice-f0de9e167e289ab7dc33e57f077c1f04ec7c68c8.zip
Remove additional unneeded tq method conversions
Diffstat (limited to 'lib/kofficecore/KoDocument.h')
-rw-r--r--lib/kofficecore/KoDocument.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/lib/kofficecore/KoDocument.h b/lib/kofficecore/KoDocument.h
index ac6de7e8..df1518de 100644
--- a/lib/kofficecore/KoDocument.h
+++ b/lib/kofficecore/KoDocument.h
@@ -385,7 +385,7 @@ public:
* @param painter The painter object onto which will be drawn.
* @param rect The rect that should be used in the painter object.
* @param transparent If true then the entire rectangle is erased before painting.
* @param view The KoView is needed to fiddle about with the active widget, when painting tqchildren.
* @param zoomX The zoom value to be applied to X coordinates when painting.
* @param zoomY The zoom value to be applied to Y coordinates when painting.
*/
@@ -399,7 +399,7 @@ public:
virtual TQPixmap generatePreview( const TQSize& size );
/**
* Paints all of the documents tqchildren into the given painter object.
*
* @param painter The painter object onto which will be drawn.
* @param rect The rect that should be used in the painter object.
@@ -427,7 +427,7 @@ public:
/**
* Paints the data itself. Normally called by paintEverything(). It does not
* paint the tqchildren.
* It's this method that %KOffice Parts have to implement.
*
* @param painter The painter object onto which will be drawn.
@@ -659,17 +659,17 @@ public:
static int defaultAutoSave() { return s_defaultAutoSave; }
/**
* @return the list of all tqchildren. Do not modify the
* returned list.
*/
- const TQPtrList<KoDocumentChild>& tqchildren() const;
+ const TQPtrList<KoDocumentChild>& children() const;
/**
* @return the KoDocumentChild associated with the given Document, but only if
* @p doc is a direct child of this document.
*
* This is a convenience function. You could get the same result
* by traversing the list returned by tqchildren().
*/
KoDocumentChild *child( KoDocument *doc );
@@ -771,14 +771,14 @@ public:
int queryCloseDia();
/**
* @brief Set when we do not want to save external tqchildren when saving our 'main' doc.
*
* This makes it possible to save 'main' doc + all its internal tqchildren first, then
* go on to save external tqchildren. Typically used by query close.
* Use:
* @code
* doc->setDoNotSaveExtDoc();
* doc->save(); // saves doc and its internal tqchildren,
* //also calls saveExternalChildren() which sets setDoNotSaveExtDoc(false)
* doc->saveExternalChildren();
* @endcode
@@ -1029,7 +1029,7 @@ protected:
*
* An example implementation may look like this:
* @code
- * TQPtrListIterator<KoDocumentChild> it( tqchildren() );
+ * TQPtrListIterator<KoDocumentChild> it( children() );
* for( ; it.current(); ++it )
* {
* if ( !it.current()->loadDocument( _store ) )
@@ -1043,16 +1043,16 @@ protected:
virtual bool loadChildren( KoStore* );
/**
- * Saves all internal tqchildren (only!).
- * @see saveExternalChildren if you have external tqchildren.
+ * Saves all internal children (only!).
+ * @see saveExternalChildren if you have external children.
* Returns true on success.
*/
virtual bool saveChildren( KoStore* store );
/**
* Saves all internal tqchildren (only!), to the store, using the OASIS format.
* This is called automatically during saveNativeFormat.
- * @see saveExternalChildren if you have external tqchildren.
+ * @see saveExternalChildren if you have external children.
* Returns true on success.
*/
virtual bool saveChildrenOasis( KoStore* store, KoXmlWriter* manifestWriter );
@@ -1077,7 +1077,7 @@ protected:
virtual bool completeSaving( KoStore* store );
/**
* Inserts the new child in the list of tqchildren and emits the
* childChanged() signal.
*
* At the same time this method marks this document as modified.
@@ -1098,9 +1098,9 @@ protected:
KoPageLayout m_pageLayout;
/**
* Saves all externally stored tqchildren.
* Returns true on success.
- * @see #saveChildren for internal tqchildren
+ * @see #saveChildren for internal children
*/
virtual bool saveExternalChildren();
@@ -385,7 +385,7 @@ public:
* @param rect The rect that should be used in the painter object.
* @param transparent If true then the entire rectangle is erased before painting.
- * @param view The KoView is needed to fiddle about with the active widget, when painting tqchildren.
+ * @param view The KoView is needed to fiddle about with the active widget, when painting children.
* @param zoomX The zoom value to be applied to X coordinates when painting.
* @param zoomY The zoom value to be applied to Y coordinates when painting.
@@ -399,7 +399,7 @@ public:
virtual TQPixmap generatePreview( const TQSize& size );
/**
- * Paints all of the documents tqchildren into the given painter object.
+ * Paints all of the documents children into the given painter object.
*
* @param painter The painter object onto which will be drawn.
@@ -427,7 +427,7 @@ public:
/**
* Paints the data itself. Normally called by paintEverything(). It does not
- * paint the tqchildren.
+ * paint the children.
* It's this method that %KOffice Parts have to implement.
*
@@ -659,17 +659,17 @@ public:
static int defaultAutoSave() { return s_defaultAutoSave; }
/**
- * @return the list of all tqchildren. Do not modify the
+ * @return the list of all children. Do not modify the
* returned list.
*/
@@ -659,17 +659,17 @@ public:
*
* This is a convenience function. You could get the same result
- * by traversing the list returned by tqchildren().
+ * by traversing the list returned by children().
*/
KoDocumentChild *child( KoDocument *doc );
@@ -771,14 +771,14 @@ public:
int queryCloseDia();
/**
- * @brief Set when we do not want to save external tqchildren when saving our 'main' doc.
+ * @brief Set when we do not want to save external children when saving our 'main' doc.
*
@@ -771,14 +771,14 @@ public:
*
- * This makes it possible to save 'main' doc + all its internal tqchildren first, then
- * go on to save external tqchildren. Typically used by query close.
+ * This makes it possible to save 'main' doc + all its internal children first, then
+ * go on to save external children. Typically used by query close.
* Use:
* @code
@@ -771,14 +771,14 @@ public:
* @code
* doc->setDoNotSaveExtDoc();
- * doc->save(); // saves doc and its internal tqchildren,
+ * doc->save(); // saves doc and its internal children,
* //also calls saveExternalChildren() which sets setDoNotSaveExtDoc(false)
* doc->saveExternalChildren();
@@ -1043,16 +1043,16 @@ protected:
virtual bool saveChildren( KoStore* store );
/**
- * Saves all internal tqchildren (only!), to the store, using the OASIS format.
+ * Saves all internal children (only!), to the store, using the OASIS format.
* This is called automatically during saveNativeFormat.
@@ -1077,7 +1077,7 @@ protected:
virtual bool completeSaving( KoStore* store );
/**
- * Inserts the new child in the list of tqchildren and emits the
+ * Inserts the new child in the list of children and emits the
* childChanged() signal.
*
@@ -1098,9 +1098,9 @@ protected:
KoPageLayout m_pageLayout;
/**
- * Saves all externally stored tqchildren.
+ * Saves all externally stored children.
* Returns true on success.